pub struct Summary { /* private fields */ }Expand description
Result summary element for a CTRF report. Corresponds to the spec’s “Summary” object.
Implementations
Sourceimpl Summary
impl Summary
Sourcepub fn new(start: SystemTime, stop: SystemTime) -> Self
pub fn new(start: SystemTime, stop: SystemTime) -> Self
Creates a report Summary instance
Sourcepub fn passed(&mut self, count: usize)
pub fn passed(&mut self, count: usize)
Sets the count of passed tests and updates the overall total
Sourcepub fn failed(&mut self, count: usize)
pub fn failed(&mut self, count: usize)
Sets the count of failed tests and updates the overall total
Sourcepub fn pending(&mut self, count: usize)
pub fn pending(&mut self, count: usize)
Sets the count of pending tests and updates the overall total
Sourcepub fn skipped(&mut self, count: usize)
pub fn skipped(&mut self, count: usize)
Sets the count of skipped tests and updates the overall total