pub enum Status {
Pending,
Skipped,
Failed,
Passed,
Other,
}Expand description
Variants
Pending
The test has not yet executed or is awaiting fulfillment of some condition.
Skipped
The test was intentionally not executed.
Failed
The test executed but did not meet all success criteria.
Passed
The test executed and met all success criteria.
Other
This is a catch-all for outcomes that do not align with any other pre-defined status. Typically indicative of a unique or library-specific status.